# Grun human pancreas (CEL-seq2) 

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This workflow performs an analysis of the @grun2016denovo CEL-seq2 dataset consisting of human pancreas cells from various donors.

## Data loading


```r
library(scRNAseq)
sce.grun <- GrunPancreasData()
```

We convert to Ensembl identifiers, and we remove duplicated genes or genes without Ensembl IDs.


```r
library(org.Hs.eg.db)
gene.ids <- mapIds(org.Hs.eg.db, keys=rowData(sce.grun)$symbol,
    keytype="SYMBOL", column="ENSEMBL")

keep <- !is.na(gene.ids) & !duplicated(gene.ids)
sce.grun <- sce.grun[keep,]
rownames(sce.grun) <- gene.ids[keep]
```

## Quality control


```r
unfiltered <- sce.grun
```

This dataset lacks mitochondrial genes so we will do without them for quality control.
We compute the median and MAD while blocking on the donor;
for donors where the assumption of a majority of high-quality cells seems to be violated (Figure \@ref(fig:unref-grun-qc-dist)),
we compute an appropriate threshold using the other donors as specified in the `subset=` argument.


```r
library(scater)
stats <- perCellQCMetrics(sce.grun)

qc <- quickPerCellQC(stats, percent_subsets="altexps_ERCC_percent",
    batch=sce.grun$donor,
    subset=sce.grun$donor %in% c("D17", "D7", "D2"))

sce.grun <- sce.grun[,!qc$discard]
```


```r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, x="donor", y="sum", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, x="donor", y="detected", colour_by="discard") +
        scale_y_log10() + ggtitle("Detected features"),
    plotColData(unfiltered, x="donor", y="altexps_ERCC_percent",
        colour_by="discard") + ggtitle("ERCC percent"),
    ncol=2
)
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-grun-qc-dist-1.png" alt="Distribution of each QC metric across cells from each donor of the Grun pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-grun-qc-dist)Distribution of each QC metric across cells from each donor of the Grun pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>


```r
colSums(as.matrix(qc), na.rm=TRUE)
```

```
##              low_lib_size            low_n_features high_altexps_ERCC_percent 
##                       452                       510                       606 
##                   discard 
##                       665
```

## Normalization 


```r
library(scran)
set.seed(1000) # for irlba. 
clusters <- quickCluster(sce.grun)
sce.grun <- computeSumFactors(sce.grun, clusters=clusters)
sce.grun <- logNormCounts(sce.grun)
```


```r
summary(sizeFactors(sce.grun))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##   0.091   0.509   0.794   1.000   1.226  11.288
```


```r
plot(librarySizeFactors(sce.grun), sizeFactors(sce.grun), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-grun-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Grun pancreas dataset." width="672" />
<p class="caption">(\#fig:unref-grun-norm)Relationship between the library size factors and the deconvolution size factors in the Grun pancreas dataset.</p>
</div>

## Variance modelling

We block on a combined plate and donor factor.


```r
block <- paste0(sce.grun$sample, "_", sce.grun$donor)
dec.grun <- modelGeneVarWithSpikes(sce.grun, spikes="ERCC", block=block)
top.grun <- getTopHVGs(dec.grun, prop=0.1)
```

We examine the number of cells in each level of the blocking factor.


```r
table(block)
```

```
## block
##                  CD13+ sorted cells_D17       CD24+ CD44+ live sorted cells_D17 
##                                      86                                      87 
##                  CD63+ sorted cells_D10                TGFBR3+ sorted cells_D17 
##                                      40                                      90 
## exocrine fraction, live sorted cells_D2 exocrine fraction, live sorted cells_D3 
##                                      82                                       7 
##        live sorted cells, library 1_D10        live sorted cells, library 1_D17 
##                                      33                                      88 
##         live sorted cells, library 1_D3         live sorted cells, library 1_D7 
##                                      25                                      85 
##        live sorted cells, library 2_D10        live sorted cells, library 2_D17 
##                                      35                                      83 
##         live sorted cells, library 2_D3         live sorted cells, library 2_D7 
##                                      27                                      84 
##         live sorted cells, library 3_D3         live sorted cells, library 3_D7 
##                                      16                                      83 
##         live sorted cells, library 4_D3         live sorted cells, library 4_D7 
##                                      29                                      83
```


```r
par(mfrow=c(6,3))
blocked.stats <- dec.grun$per.block
for (i in colnames(blocked.stats)) {
    current <- blocked.stats[[i]]
    plot(current$mean, current$total, main=i, pch=16, cex=0.5,
        xlab="Mean of log-expression", ylab="Variance of log-expression")
    curfit <- metadata(current)
    points(curfit$mean, curfit$var, col="red", pch=16)
    curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-416b-variance-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Grun pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor." width="672" />
<p class="caption">(\#fig:unref-416b-variance)Per-gene variance as a function of the mean for the log-expression values in the Grun pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor.</p>
</div>

## Data integration


```r
library(batchelor)
set.seed(1001010)
merged.grun <- fastMNN(sce.grun, subset.row=top.grun, batch=sce.grun$donor)
```


```r
metadata(merged.grun)$merge.info$lost.var
```

```
##           D10      D17      D2      D3      D7
## [1,] 0.030471 0.032084 0.00000 0.00000 0.00000
## [2,] 0.008026 0.012137 0.03948 0.00000 0.00000
## [3,] 0.004062 0.005264 0.00791 0.05313 0.00000
## [4,] 0.013849 0.016772 0.01680 0.01560 0.05562
```

## Dimensionality reduction


```r
set.seed(100111)
merged.grun <- runTSNE(merged.grun, dimred="corrected")
```

## Clustering


```r
snn.gr <- buildSNNGraph(merged.grun, use.dimred="corrected")
colLabels(merged.grun) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


```r
table(Cluster=colLabels(merged.grun), Donor=merged.grun$batch)
```

```
##        Donor
## Cluster D10 D17  D2  D3  D7
##      1   32  70  31  80  28
##      2   14  36   3   2  70
##      3    3   9   3   3   6
##      4   11 119   0   0  55
##      5    5  14   0   0  10
##      6   11  69  30   2  72
##      7    1   9   0   0   7
##      8   16  38  13  11  44
##      9    3   2   2   4   2
##      10   3  38   0   0   7
##      11   4  13   0   0   1
##      12   5  17   0   2  33
```


```r
gridExtra::grid.arrange(
    plotTSNE(merged.grun, colour_by="label"),
    plotTSNE(merged.grun, colour_by="batch"),
    ncol=2
)
```

<div class="figure">
<img src="grun-pancreas_files/figure-html/unref-grun-tsne-1.png" alt="Obligatory $t$-SNE plots of the Grun pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right)." width="672" />
<p class="caption">(\#fig:unref-grun-tsne)Obligatory $t$-SNE plots of the Grun pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right).</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.3.1 (2023-06-16)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 22.04.3 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.18-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.10.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] BiocSingular_1.18.0         batchelor_1.18.0           
 [3] scran_1.30.0                scater_1.30.0              
 [5] ggplot2_3.4.4               scuttle_1.12.0             
 [7] org.Hs.eg.db_3.18.0         AnnotationDbi_1.64.0       
 [9] Matrix_1.6-1.1              scRNAseq_2.15.0            
[11] SingleCellExperiment_1.24.0 SummarizedExperiment_1.32.0
[13] Biobase_2.62.0              GenomicRanges_1.54.0       
[15] GenomeInfoDb_1.38.0         IRanges_2.36.0             
[17] S4Vectors_0.40.0            BiocGenerics_0.48.0        
[19] MatrixGenerics_1.14.0       matrixStats_1.0.0          
[21] BiocStyle_2.30.0            rebook_1.12.0              

loaded via a namespace (and not attached):
  [1] rstudioapi_0.15.0             jsonlite_1.8.7               
  [3] CodeDepends_0.6.5             magrittr_2.0.3               
  [5] ggbeeswarm_0.7.2              GenomicFeatures_1.54.0       
  [7] farver_2.1.1                  rmarkdown_2.25               
  [9] BiocIO_1.12.0                 zlibbioc_1.48.0              
 [11] vctrs_0.6.4                   memoise_2.0.1                
 [13] Rsamtools_2.18.0              DelayedMatrixStats_1.24.0    
 [15] RCurl_1.98-1.12               htmltools_0.5.6.1            
 [17] S4Arrays_1.2.0                progress_1.2.2               
 [19] AnnotationHub_3.10.0          curl_5.1.0                   
 [21] BiocNeighbors_1.20.0          SparseArray_1.2.0            
 [23] sass_0.4.7                    bslib_0.5.1                  
 [25] cachem_1.0.8                  ResidualMatrix_1.12.0        
 [27] GenomicAlignments_1.38.0      igraph_1.5.1                 
 [29] mime_0.12                     lifecycle_1.0.3              
 [31] pkgconfig_2.0.3               rsvd_1.0.5                   
 [33] R6_2.5.1                      fastmap_1.1.1                
 [35] GenomeInfoDbData_1.2.11       shiny_1.7.5.1                
 [37] digest_0.6.33                 colorspace_2.1-0             
 [39] dqrng_0.3.1                   irlba_2.3.5.1                
 [41] ExperimentHub_2.10.0          RSQLite_2.3.1                
 [43] beachmat_2.18.0               labeling_0.4.3               
 [45] filelock_1.0.2                fansi_1.0.5                  
 [47] httr_1.4.7                    abind_1.4-5                  
 [49] compiler_4.3.1                bit64_4.0.5                  
 [51] withr_2.5.1                   BiocParallel_1.36.0          
 [53] viridis_0.6.4                 DBI_1.1.3                    
 [55] biomaRt_2.58.0                rappdirs_0.3.3               
 [57] DelayedArray_0.28.0           bluster_1.12.0               
 [59] rjson_0.2.21                  tools_4.3.1                  
 [61] vipor_0.4.5                   beeswarm_0.4.0               
 [63] interactiveDisplayBase_1.40.0 httpuv_1.6.12                
 [65] glue_1.6.2                    restfulr_0.0.15              
 [67] promises_1.2.1                grid_4.3.1                   
 [69] Rtsne_0.16                    cluster_2.1.4                
 [71] generics_0.1.3                gtable_0.3.4                 
 [73] ensembldb_2.26.0              hms_1.1.3                    
 [75] metapod_1.10.0                ScaledMatrix_1.10.0          
 [77] xml2_1.3.5                    utf8_1.2.4                   
 [79] XVector_0.42.0                ggrepel_0.9.4                
 [81] BiocVersion_3.18.0            pillar_1.9.0                 
 [83] stringr_1.5.0                 limma_3.58.0                 
 [85] later_1.3.1                   dplyr_1.1.3                  
 [87] BiocFileCache_2.10.0          lattice_0.22-5               
 [89] rtracklayer_1.62.0            bit_4.0.5                    
 [91] tidyselect_1.2.0              locfit_1.5-9.8               
 [93] Biostrings_2.70.0             knitr_1.44                   
 [95] gridExtra_2.3                 bookdown_0.36                
 [97] ProtGenerics_1.34.0           edgeR_4.0.0                  
 [99] xfun_0.40                     statmod_1.5.0                
[101] stringi_1.7.12                lazyeval_0.2.2               
[103] yaml_2.3.7                    evaluate_0.22                
[105] codetools_0.2-19              tibble_3.2.1                 
[107] BiocManager_1.30.22           graph_1.80.0                 
[109] cli_3.6.1                     xtable_1.8-4                 
[111] munsell_0.5.0                 jquerylib_0.1.4              
[113] Rcpp_1.0.11                   dir.expiry_1.10.0            
[115] dbplyr_2.3.4                  png_0.1-8                    
[117] XML_3.99-0.14                 parallel_4.3.1               
[119] ellipsis_0.3.2                blob_1.2.4                   
[121] prettyunits_1.2.0             AnnotationFilter_1.26.0      
[123] sparseMatrixStats_1.14.0      bitops_1.0-7                 
[125] viridisLite_0.4.2             scales_1.2.1                 
[127] purrr_1.0.2                   crayon_1.5.2                 
[129] rlang_1.1.1                   cowplot_1.1.1                
[131] KEGGREST_1.42.0              
```
</div>
