# Messmer human ESC (Smart-seq2) {#messmer-hesc}

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the human embryonic stem cell (hESC) dataset generated with Smart-seq2 [@messmer2019transcriptional], which contains several plates of naive and primed hESCs.
The chapter's code is based on the steps in the paper's [GitHub repository](https://github.com/MarioniLab/NaiveHESC2016/blob/master/analysis/preprocess.Rmd), with some additional steps for cell cycle effect removal contributed by Philippe Boileau.

## Data loading

Converting the batch to a factor, to make life easier later on.


```r
library(scRNAseq)
sce.mess <- MessmerESCData()
sce.mess$`experiment batch` <- factor(sce.mess$`experiment batch`)
```


```r
library(AnnotationHub)
ens.hs.v97 <- AnnotationHub()[["AH73881"]]
anno <- select(ens.hs.v97, keys=rownames(sce.mess), 
    keytype="GENEID", columns=c("SYMBOL"))
rowData(sce.mess) <- anno[match(rownames(sce.mess), anno$GENEID),]
```

## Quality control



Let's have a look at the QC statistics.


```r
colSums(as.matrix(filtered))
```

```
##              low_lib_size            low_n_features high_subsets_Mito_percent 
##                       107                        99                        22 
## high_altexps_ERCC_percent                   discard 
##                       117                       156
```


```r
gridExtra::grid.arrange(
    plotColData(original, x="experiment batch", y="sum",
        colour_by=I(filtered$discard), other_field="phenotype") +
        facet_wrap(~phenotype) + scale_y_log10(),
    plotColData(original, x="experiment batch", y="detected",
        colour_by=I(filtered$discard), other_field="phenotype") +
        facet_wrap(~phenotype) + scale_y_log10(),
    plotColData(original, x="experiment batch", y="subsets_Mito_percent",
        colour_by=I(filtered$discard), other_field="phenotype") +
        facet_wrap(~phenotype),
    plotColData(original, x="experiment batch", y="altexps_ERCC_percent",
        colour_by=I(filtered$discard), other_field="phenotype") +
        facet_wrap(~phenotype),
    ncol=1
)
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-qc-1.png" alt="Distribution of QC metrics across batches (x-axis) and phenotypes (facets) for cells in the Messmer hESC dataset. Each point is a cell and is colored by whether it was discarded." width="576" />
<p class="caption">(\#fig:unref-messmer-hesc-qc)Distribution of QC metrics across batches (x-axis) and phenotypes (facets) for cells in the Messmer hESC dataset. Each point is a cell and is colored by whether it was discarded.</p>
</div>

## Normalization


```r
library(scran)

set.seed(10000)
clusters <- quickCluster(sce.mess)
sce.mess <- computeSumFactors(sce.mess, cluster=clusters)
sce.mess <- logNormCounts(sce.mess)
```


```r
par(mfrow=c(1,2))
plot(sce.mess$sum, sizeFactors(sce.mess), log = "xy", pch=16,
     xlab = "Library size (millions)", ylab = "Size factor",
     col = ifelse(sce.mess$phenotype == "naive", "black", "grey"))

spike.sf <- librarySizeFactors(altExp(sce.mess, "ERCC"))
plot(sizeFactors(sce.mess), spike.sf, log = "xy", pch=16,
     ylab = "Spike-in size factor", xlab = "Deconvolution size factor",
     col = ifelse(sce.mess$phenotype == "naive", "black", "grey"))
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-norm-1.png" alt="Deconvolution size factors plotted against the library size (left) and spike-in size factors plotted against the deconvolution size factors (right). Each point is a cell and is colored by its phenotype." width="672" />
<p class="caption">(\#fig:unref-messmer-hesc-norm)Deconvolution size factors plotted against the library size (left) and spike-in size factors plotted against the deconvolution size factors (right). Each point is a cell and is colored by its phenotype.</p>
</div>

## Cell cycle phase assignment

Here, we use multiple cores to speed up the processing.


```r
set.seed(10001)
hs_pairs <- readRDS(system.file("exdata", "human_cycle_markers.rds", package="scran"))
assigned <- cyclone(sce.mess, pairs=hs_pairs, 
    gene.names=rownames(sce.mess),
    BPPARAM=BiocParallel::MulticoreParam(10))
sce.mess$phase <- assigned$phases
```


```r
table(sce.mess$phase)
```

```
## 
##  G1 G2M   S 
## 460 406 322
```


```r
smoothScatter(assigned$scores$G1, assigned$scores$G2M, xlab="G1 score",
     ylab="G2/M score", pch=16)
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-cyclone-1.png" alt="G1 `cyclone()` phase scores against the G2/M phase scores for each cell in the Messmer hESC dataset." width="672" />
<p class="caption">(\#fig:unref-messmer-hesc-cyclone)G1 `cyclone()` phase scores against the G2/M phase scores for each cell in the Messmer hESC dataset.</p>
</div>

## Feature selection


```r
dec <- modelGeneVarWithSpikes(sce.mess, "ERCC", block = sce.mess$`experiment batch`)
top.hvgs <- getTopHVGs(dec, prop = 0.1)
```


```r
par(mfrow=c(1,3))
for (i in seq_along(dec$per.block)) {
    current <- dec$per.block[[i]]
    plot(current$mean, current$total, xlab="Mean log-expression", 
        ylab="Variance", pch=16, cex=0.5, main=paste("Batch", i))

    fit <- metadata(current)
    points(fit$mean, fit$var, col="red", pch=16)
    curve(fit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-var-1.png" alt="Per-gene variance of the log-normalized expression values in the Messmer hESC dataset, plotted against the mean for each batch. Each point represents a gene with spike-ins shown in red and the fitted trend shown in blue." width="1152" />
<p class="caption">(\#fig:unref-messmer-hesc-var)Per-gene variance of the log-normalized expression values in the Messmer hESC dataset, plotted against the mean for each batch. Each point represents a gene with spike-ins shown in red and the fitted trend shown in blue.</p>
</div>

## Batch correction 

We eliminate the obvious batch effect between batches with linear regression, which is possible due to the replicated nature of the experimental design.
We set `keep=1:2` to retain the effect of the first two coefficients in `design` corresponding to our phenotype of interest.


```r
library(batchelor)
sce.mess <- correctExperiments(sce.mess, 
    PARAM = RegressParam(
        design = model.matrix(~sce.mess$phenotype + sce.mess$`experiment batch`),
        keep = 1:2 
    )
)
```

## Dimensionality Reduction

We could have set `d=` and `subset.row=` in `correctExperiments()` to automatically perform a PCA on the the residual matrix with the subset of HVGs,
but we'll just explicitly call `runPCA()` here to keep things simple.


```r
set.seed(1101001)
sce.mess <- runPCA(sce.mess, subset_row = top.hvgs, exprs_values = "corrected")
sce.mess <- runTSNE(sce.mess, dimred = "PCA", perplexity = 40)
```

From a naive PCA, the cell cycle appears to be a major source of biological variation within each phenotype.


```r
gridExtra::grid.arrange(
    plotTSNE(sce.mess, colour_by = "phenotype") + ggtitle("By phenotype"),
    plotTSNE(sce.mess, colour_by = "experiment batch") + ggtitle("By batch "),
    plotTSNE(sce.mess, colour_by = "CDK1", swap_rownames="SYMBOL") + ggtitle("By CDK1"),
    plotTSNE(sce.mess, colour_by = "phase") + ggtitle("By phase"),
    ncol = 2
)
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-tsne-1.png" alt="Obligatory $t$-SNE plots of the Messmer hESC dataset, where each point is a cell and is colored by various attributes." width="960" />
<p class="caption">(\#fig:unref-messmer-hesc-tsne)Obligatory $t$-SNE plots of the Messmer hESC dataset, where each point is a cell and is colored by various attributes.</p>
</div>

We perform contrastive PCA (cPCA) and sparse cPCA (scPCA) on the corrected log-expression data to obtain the same number of PCs.
Given that the naive hESCs are actually reprogrammed primed hESCs, we will use the single batch of primed-only hESCs as the "background" dataset to remove the cell cycle effect.


```r
library(scPCA)
is.bg <- sce.mess$`experiment batch`=="3"
target <- sce.mess[,!is.bg]
background <- sce.mess[,is.bg]

mat.target <- t(assay(target, "corrected")[top.hvgs,])
mat.background <- t(assay(background, "corrected")[top.hvgs,])

set.seed(1010101001)
con_out <- scPCA(
    target = mat.target,
    background = mat.background,
    penalties = 0, # no penalties = non-sparse cPCA.
    n_eigen = 50,
    contrasts = 100
)
reducedDim(target, "cPCA") <- con_out$x
```


```r
set.seed(101010101)
sparse_con_out <- scPCA(
    target = mat.target,
    background = mat.background,
    penalties = 1e-4,
    n_eigen = 50,
    contrasts = 100,
    alg = "rand_var_proj" # for speed.
)
reducedDim(target, "scPCA") <- sparse_con_out$x
```

We see greater intermingling between phases within both the naive and primed cells after cPCA and scPCA.


```r
set.seed(1101001)
target <- runTSNE(target, dimred = "cPCA", perplexity = 40, name="cPCA+TSNE")
target <- runTSNE(target, dimred = "scPCA", perplexity = 40, name="scPCA+TSNE")
```


```r
gridExtra::grid.arrange(
    plotReducedDim(target, "cPCA+TSNE", colour_by = "phase") + ggtitle("After cPCA"),
    plotReducedDim(target, "scPCA+TSNE", colour_by = "phase") + ggtitle("After scPCA"),
    ncol=2
)
```

<div class="figure">
<img src="messmer-hesc_files/figure-html/unref-messmer-hesc-cpca-tsne-1.png" alt="More $t$-SNE plots of the Messmer hESC dataset after cPCA and scPCA, where each point is a cell and is colored by its assigned cell cycle phase." width="960" />
<p class="caption">(\#fig:unref-messmer-hesc-cpca-tsne)More $t$-SNE plots of the Messmer hESC dataset after cPCA and scPCA, where each point is a cell and is colored by its assigned cell cycle phase.</p>
</div>

We can quantify the change in the separation between phases within each phenotype using the silhouette coefficient.


```r
library(bluster)
naive <- target[,target$phenotype=="naive"]
primed <- target[,target$phenotype=="primed"]

N <- approxSilhouette(reducedDim(naive, "PCA"), naive$phase)
P <- approxSilhouette(reducedDim(primed, "PCA"), primed$phase)
c(naive=mean(N$width), primed=mean(P$width))
```

```
##   naive  primed 
## 0.02032 0.03025
```

```r
cN <- approxSilhouette(reducedDim(naive, "cPCA"), naive$phase)
cP <- approxSilhouette(reducedDim(primed, "cPCA"), primed$phase)
c(naive=mean(cN$width), primed=mean(cP$width))
```

```
##    naive   primed 
## 0.007696 0.011941
```

```r
scN <- approxSilhouette(reducedDim(naive, "scPCA"), naive$phase)
scP <- approxSilhouette(reducedDim(primed, "scPCA"), primed$phase)
c(naive=mean(scN$width), primed=mean(scP$width))
```

```
##    naive   primed 
## 0.006614 0.014601
```



## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.3.1 (2023-06-16)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: Ubuntu 22.04.3 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.18-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.10.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] bluster_1.12.0              scPCA_1.16.0               
 [3] ResidualMatrix_1.12.0       batchelor_1.18.0           
 [5] scran_1.30.0                scater_1.30.0              
 [7] ggplot2_3.4.4               scuttle_1.12.0             
 [9] AnnotationHub_3.10.0        BiocFileCache_2.10.0       
[11] dbplyr_2.3.4                ensembldb_2.26.0           
[13] AnnotationFilter_1.26.0     GenomicFeatures_1.54.0     
[15] AnnotationDbi_1.64.0        scRNAseq_2.15.0            
[17] SingleCellExperiment_1.24.0 SummarizedExperiment_1.32.0
[19] Biobase_2.62.0              GenomicRanges_1.54.0       
[21] GenomeInfoDb_1.38.0         IRanges_2.36.0             
[23] S4Vectors_0.40.0            BiocGenerics_0.48.0        
[25] MatrixGenerics_1.14.0       matrixStats_1.0.0          
[27] BiocStyle_2.30.0            rebook_1.12.0              

loaded via a namespace (and not attached):
  [1] later_1.3.1                   BiocIO_1.12.0                
  [3] bitops_1.0-7                  filelock_1.0.2               
  [5] tibble_3.2.1                  CodeDepends_0.6.5            
  [7] graph_1.80.0                  XML_3.99-0.14                
  [9] lifecycle_1.0.3               Rdpack_2.5                   
 [11] edgeR_4.0.0                   globals_0.16.2               
 [13] lattice_0.22-5                magrittr_2.0.3               
 [15] limma_3.58.0                  sass_0.4.7                   
 [17] rmarkdown_2.25                jquerylib_0.1.4              
 [19] yaml_2.3.7                    metapod_1.10.0               
 [21] httpuv_1.6.12                 cowplot_1.1.1                
 [23] DBI_1.1.3                     abind_1.4-5                  
 [25] zlibbioc_1.48.0               Rtsne_0.16                   
 [27] purrr_1.0.2                   RCurl_1.98-1.12              
 [29] rappdirs_0.3.3                GenomeInfoDbData_1.2.11      
 [31] ggrepel_0.9.4                 irlba_2.3.5.1                
 [33] listenv_0.9.0                 RSpectra_0.16-1              
 [35] parallelly_1.36.0             dqrng_0.3.1                  
 [37] DelayedMatrixStats_1.24.0     codetools_0.2-19             
 [39] DelayedArray_0.28.0           xml2_1.3.5                   
 [41] tidyselect_1.2.0              farver_2.1.1                 
 [43] ScaledMatrix_1.10.0           viridis_0.6.4                
 [45] GenomicAlignments_1.38.0      jsonlite_1.8.7               
 [47] BiocNeighbors_1.20.0          ellipsis_0.3.2               
 [49] tools_4.3.1                   progress_1.2.2               
 [51] Rcpp_1.0.11                   glue_1.6.2                   
 [53] gridExtra_2.3                 SparseArray_1.2.0            
 [55] xfun_0.40                     dplyr_1.1.3                  
 [57] withr_2.5.1                   BiocManager_1.30.22          
 [59] fastmap_1.1.1                 sparsepca_0.1.2              
 [61] fansi_1.0.5                   digest_0.6.33                
 [63] rsvd_1.0.5                    R6_2.5.1                     
 [65] mime_0.12                     colorspace_2.1-0             
 [67] biomaRt_2.58.0                RSQLite_2.3.1                
 [69] utf8_1.2.4                    generics_0.1.3               
 [71] data.table_1.14.8             rtracklayer_1.62.0           
 [73] prettyunits_1.2.0             httr_1.4.7                   
 [75] S4Arrays_1.2.0                pkgconfig_2.0.3              
 [77] gtable_0.3.4                  blob_1.2.4                   
 [79] XVector_0.42.0                htmltools_0.5.6.1            
 [81] bookdown_0.36                 ProtGenerics_1.34.0          
 [83] scales_1.2.1                  png_0.1-8                    
 [85] knitr_1.44                    rstudioapi_0.15.0            
 [87] rjson_0.2.21                  curl_5.1.0                   
 [89] cachem_1.0.8                  stringr_1.5.0                
 [91] BiocVersion_3.18.0            KernSmooth_2.23-22           
 [93] parallel_4.3.1                vipor_0.4.5                  
 [95] restfulr_0.0.15               pillar_1.9.0                 
 [97] grid_4.3.1                    vctrs_0.6.4                  
 [99] promises_1.2.1                origami_1.0.7                
[101] BiocSingular_1.18.0           beachmat_2.18.0              
[103] xtable_1.8-4                  cluster_2.1.4                
[105] beeswarm_0.4.0                evaluate_0.22                
[107] cli_3.6.1                     locfit_1.5-9.8               
[109] compiler_4.3.1                Rsamtools_2.18.0             
[111] rlang_1.1.1                   crayon_1.5.2                 
[113] future.apply_1.11.0           labeling_0.4.3               
[115] ggbeeswarm_0.7.2              stringi_1.7.12               
[117] viridisLite_0.4.2             BiocParallel_1.36.0          
[119] assertthat_0.2.1              munsell_0.5.0                
[121] Biostrings_2.70.0             coop_0.6-3                   
[123] lazyeval_0.2.2                Matrix_1.6-1.1               
[125] dir.expiry_1.10.0             ExperimentHub_2.10.0         
[127] hms_1.1.3                     future_1.33.0                
[129] sparseMatrixStats_1.14.0      bit64_4.0.5                  
[131] KEGGREST_1.42.0               statmod_1.5.0                
[133] shiny_1.7.5.1                 interactiveDisplayBase_1.40.0
[135] kernlab_0.9-32                rbibutils_2.2.15             
[137] igraph_1.5.1                  memoise_2.0.1                
[139] bslib_0.5.1                   bit_4.0.5                    
```
</div>
